@@ -17,6 +17,8 @@ def main():
     parser = argparse.ArgumentParser(description='Badger the optimizer')
     parser.add_argument('-g', '--gui', action='store_true',
                         help='launch the GUI')
+    parser.add_argument('-ga', '--gui-acr', action='store_true',
+                        help='launch the GUI for ACR')
     parser.set_defaults(func=show_info)
     subparsers = parser.add_subparsers(help='Badger commands help')
 
