@@ -417,6 +417,10 @@ def str_to_ts(timestr, format='lcls-log'):
         return datetime.fromisoformat(timestr)
 
 
+def curr_ts():
+    return datetime.now()
+
+
 def curr_ts_to_str(format='lcls-log'):
     return ts_to_str(datetime.now(), format)
 
@@ -476,3 +480,56 @@ def instantiate_env(env_class, configs, manager=None):
     env = env_class(intf, configs['params'])
 
     return env
+
+
+def get_header(routine):
+    try:
+        obj_names = [next(iter(d))
+                        for d in routine['config']['objectives']]
+    except:
+        obj_names = []
+    try:
+        var_names = [next(iter(d))
+                        for d in routine['config']['variables']]
+    except:
+        var_names = []
+    try:
+        if routine['config']['constraints']:
+            con_names = [next(iter(d))
+                            for d in routine['config']['constraints']]
+        else:
+            con_names = []
+    except:
+        con_names = []
+
+    return obj_names + con_names + var_names
+
+
+def run_names_to_dict(run_names):
+    runs = {}
+    for name in run_names:
+        tokens = name.split('-')
+        year = tokens[1]
+        month = tokens[2]
+        day = tokens[3]
+
+        try:
+            year_dict = runs[year]
+        except:
+            runs[year] = {}
+            year_dict = runs[year]
+        key_month = f'{year}-{month}'
+        try:
+            month_dict = year_dict[key_month]
+        except:
+            year_dict[key_month] = {}
+            month_dict = year_dict[key_month]
+        key_day = f'{year}-{month}-{day}'
+        try:
+            day_list = month_dict[key_day]
+        except:
+            month_dict[key_day] = []
+            day_list = month_dict[key_day]
+        day_list.append(name)
+
+    return runs
